@@ -12,8 +12,6 @@
 #
 ##############################################################################
 """Test the choice collections widgets (function).
-
-$Id: test_choicecollections.py 112015 2010-05-05 18:27:23Z tseaver $
 """
 import unittest
 from zope.component.testing import PlacelessSetup
@@ -43,7 +41,7 @@ class ListOfChoicesWidgetTest(PlacelessSetup, unittest.TestCase):
         field = List(value_type=Choice(values=[1, 2, 3]))
         bound = field.bind(object())
         widget = CollectionDisplayWidget(bound, TestRequest())
-        self.assert_(isinstance(widget, ItemsMultiDisplayWidget))
+        self.assertTrue(isinstance(widget, ItemsMultiDisplayWidget))
         self.assertEqual(widget.context, bound)
         self.assertEqual(widget.vocabulary, bound.value_type.vocabulary)
 
@@ -58,7 +56,7 @@ class ListOfChoicesWidgetTest(PlacelessSetup, unittest.TestCase):
         field = List(value_type=Choice(values=[1, 2, 3]))
         bound = field.bind(object())
         widget = CollectionInputWidget(bound, TestRequest())
-        self.assert_(isinstance(widget, SelectWidget))
+        self.assertTrue(isinstance(widget, SelectWidget))
         self.assertEqual(widget.context, bound)
         self.assertEqual(widget.vocabulary, bound.value_type.vocabulary)
         
