@@ -12,12 +12,10 @@
 #
 ##############################################################################
 """RadioWidget Tests
-
-$Id: test_functional_selectwidget.py 112015 2010-05-05 18:27:23Z tseaver $
 """
 import unittest
 
-from zope.interface import Interface, implements
+from zope.interface import Interface, implementer
 from zope.schema import Choice
 from zope.formlib import form
 from zope.publisher.browser import TestRequest
@@ -38,10 +36,9 @@ class IRadioTest(Interface):
         required=True,
         values=(u'1', u'2', u'3'))
 
+@implementer(IRadioTest)
 class RadioTest(object):
 
-    implements(IRadioTest)
-
     def __init__(self):
         self.s3 = None
         self.s4 = u'1'
@@ -64,40 +61,40 @@ class Test(FunctionalWidgetTestCase):
         html = Form(foo, request)()
         
         # S3
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<select .* name="form.s3".*>',
             html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option selected="selected" value="">',
             html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option value="Bob">',
             html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option value="is">',
             html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option value="Your">',
             html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option value="Uncle">',
             html))
 
         # S4
         joined_body = "".join(html.split("\n"))
-        self.failIf(patternExists(
+        self.assertFalse(patternExists(
             '<select.*name="form.s4".*>.*<option.*value="".*>',
             joined_body))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<select .* name="form.s4".*>',
             html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option selected="selected" value="1">',
             html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option value="2">',
             html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option value="3">',
             html))
 
@@ -109,19 +106,19 @@ class Test(FunctionalWidgetTestCase):
         # display edit view
         html = Form(foo, request)()
 
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option selected="selected" value="Bob">',
             html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option selected="selected" value="2">',
             html))
 
         
         html = Form(foo, request)()
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option selected="selected" value="Bob">',
             html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option selected="selected" value="2">',
             html))
 
@@ -130,17 +127,17 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.actions.apply'] = u''
         
         html = Form(foo, request)()
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option selected="selected" value="">',
             html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option selected="selected" value="2">',
             html))
 
         request = TestRequest()
         html = Form(foo, request)()
 
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option selected="selected" value="">',
             html))
 
