@@ -57,25 +57,25 @@ class Test(FunctionalWidgetTestCase):
         (zope.schema.interfaces.IChoice, ChoiceInputWidget),
         ((zope.schema.interfaces.IChoice, zope.schema.interfaces.IVocabularyTokenized),
          DropdownWidget)]
-        
+
     def test_display_editform(self):
         foo = TextLineTest()
         request = TestRequest()
 
         # display edit view
-        
+
         html = Form(foo, request)()
-        
+
         # s1 and s2 should be displayed in text fields
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<input .* name="form.s1".* value="".*>', html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<input .* name="form.s2".* value="foo".*>', html))
 
         # s3 should be in a dropdown
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<select .*name="form.s3".*>', html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option selected="selected" value="">.*</option>',
             html))
 
@@ -108,10 +108,10 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.s1'] = ''
         request.form['form.actions.apply'] = u''
         html = Form(foo, request)()
-        
+
         # We don't have a invalid field value
         # since we convert the value to unicode
-        self.assert_('Object is of wrong type.' not in html)
+        self.assertTrue('Object is of wrong type.' not in html)
 
     def test_missing_value(self):
         foo = TextLineTest()
@@ -122,7 +122,7 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.s3'] = u''
         request.form['form.actions.apply'] = u''
         Form(foo, request)()
-        
+
         # check new values in object
         self.assertEqual(foo.s1, u'foo')
         self.assertEqual(foo.s2, u'')   # default missing_value
@@ -137,14 +137,14 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.s3'] = u''
         request.form['form.actions.apply'] = u''
         html = Form(foo, request)()
-        
+
         # confirm error msgs
         s1_index = html.find('form.s1')
         s2_index = html.find('form.s2')
         missing_index = html.find('missing')
 
-        self.assert_(s1_index < missing_index < s2_index)
-        self.assert_(html.find('missing', s2_index) == -1)
+        self.assertTrue(s1_index < missing_index < s2_index)
+        self.assertTrue(html.find('missing', s2_index) == -1)
 
     def test_invalid_value(self):
         foo = TextLineTest()
@@ -157,35 +157,35 @@ class Test(FunctionalWidgetTestCase):
 
         s3_index = html.find('form.s3')
         invalid_index = html.find('Invalid')
-        self.assert_(invalid_index != -1)
-        self.assert_(invalid_index > s3_index)
+        self.assertTrue(invalid_index != -1)
+        self.assertTrue(invalid_index > s3_index)
 
     def test_length_validation(self):
         foo = TextLineTest()
         request = TestRequest()
-        
+
         # submit value for s1 that is too short
         request.form['form.s1'] = u'a'
         request.form['form.actions.apply'] = u''
         html = Form(foo, request)()
 
-        self.assert_('Value is too short' in html)
+        self.assertTrue('Value is too short' in html)
 
         # submit value for s1 that is too long
         request.form['form.s1'] = u'12345678901'
         request.form['form.actions.apply'] = u''
         html = Form(foo, request)()
 
-        self.assert_('Value is too long' in html)
+        self.assertTrue('Value is too long' in html)
 
     def test_omitted_value(self):
         foo = TextLineTest()
         request = TestRequest()
-        
+
         # confirm default values
         self.assertEqual(foo.s1, '')
         self.assertEqual(foo.s2, u'foo')
-        self.assert_(foo.s3 is None)
+        self.assertTrue(foo.s3 is None)
 
         # submit change with only s2 present -- note that required
         # field s1 is omitted, which should not cause a validation error
@@ -196,7 +196,7 @@ class Test(FunctionalWidgetTestCase):
         # check new value in object
         self.assertEqual(foo.s1, '')
         self.assertEqual(foo.s2, u'bar')
-        self.assert_(foo.s3 is None)
+        self.assertTrue(foo.s3 is None)
 
 def test_suite():
     suite = unittest.TestSuite()
